( cd usr/share/doc/HTML/da/kchart ; rm -rf common )
( cd usr/share/doc/HTML/da/kchart ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/karbon ; rm -rf common )
( cd usr/share/doc/HTML/da/karbon ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/krita ; rm -rf common )
( cd usr/share/doc/HTML/da/krita ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kplato ; rm -rf common )
( cd usr/share/doc/HTML/da/kplato ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kugar ; rm -rf common )
( cd usr/share/doc/HTML/da/kugar ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kspread ; rm -rf common )
( cd usr/share/doc/HTML/da/kspread ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kword ; rm -rf common )
( cd usr/share/doc/HTML/da/kword ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/koffice ; rm -rf common )
( cd usr/share/doc/HTML/da/koffice ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/thesaurus ; rm -rf common )
( cd usr/share/doc/HTML/da/thesaurus ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kpresenter ; rm -rf common )
( cd usr/share/doc/HTML/da/kpresenter ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/koshell ; rm -rf common )
( cd usr/share/doc/HTML/da/koshell ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kivio ; rm -rf common )
( cd usr/share/doc/HTML/da/kivio ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kformula ; rm -rf common )
( cd usr/share/doc/HTML/da/kformula ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/da/kexi ; rm -rf common )
( cd usr/share/doc/HTML/da/kexi ; ln -sf /usr/share/doc/HTML/da/common common )
